==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../AutoSave.js" line="+34"/>
        <source>Load/Save</source>
        <translation>Загрузить/Сохранить</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Autosave</source>
        <translation>Автосохранение</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>Автосохранение в:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>Автосохранение неудачно:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Автосохранение завершено.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation>Был найден &apos;автосохранённый&apos; файл резервного копирования
для безымянного чертежа. Вы хотите восстановить его?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation>Были найдены &apos;автосохранённые&apos; файлы резервного копирования
для безымянного чертежа: %1. Вы хотите восстановить их?</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Recover Files?</source>
        <translation>Перезаписать файлы?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>Восстановлено</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Восстановить файл?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Существует &apos;автосохранённый&apos; файл резервного копирования
для &apos;%1&apos;. Вы хотите восстановить его?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Не удается переименовать файл:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Файл автосохранения перемещен в:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Оригинальный файл перемещен в:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Не удалось удалить файл:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Включить автосохранение</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Интервал автосохранения:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>мин</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AutoSave</name>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Загрузить/Сохранить</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+35"/>
        <source>Autosave</source>
        <translation>Автосохранение</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>Автосохранение в:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>Автосохранение неудачно:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Автосохранение завершено.</translation>
    </message>
    <message>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation type="vanished">Был найден &apos;автосохранённый&apos; файл резервного копирования
для безымянного чертежа. Вы хотите восстановить его?</translation>
    </message>
    <message>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation type="vanished">Были найдены &apos;автосохранённые&apos; файлы резервного копирования
для безымянного чертежа: %1. Вы хотите восстановить их?</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source>%n &apos;autosave&apos; backup file(s) for (an) untitled drawing(s) was/were found.
Do you wish to recover it/them?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Recover Files?</source>
        <translation>Перезаписать файлы?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>Восстановлено</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Восстановить файл?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Существует &apos;автосохранённый&apos; файл резервного копирования
для &apos;%1&apos;. Вы хотите восстановить его?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Не удается переименовать файл:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Файл автосохранения перемещен в:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Оригинальный файл перемещен в:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Не удалось удалить файл:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Включить автосохранение</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Интервал автосохранения:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>мин</translation>
    </message>
</context>
</TS>
